@@ -10,6 +10,7 @@ def parse_input():
     parser.add_option("-r", "--report", action="store_true", dest="report", default=False, help="(event listener) status report every 5 seconds (non-pyevent only)")
     parser.add_option("-v", "--verbose", action="store_true", dest="verbose", default=False, help="(event listener) verbose output")
     parser.add_option("-s", "--strict", action="store_true", dest="strict", default=False, help="(event listener) _only_ try specified notification method")
+    parser.add_option("-t", "--threaded", action="store_true", dest="threaded", default=False, help="(event listener) enable GIL hack to run threaded pyevent 0.3 application")
     return parser.parse_args()[0]
 
 def error(msg):
@@ -26,6 +27,8 @@ def main():
         rel_options.append('verbose')
     if options.strict:
         rel_options.append('strict')
+    if options.threaded:
+        rel_options.append('threaded')
     rel.initialize([options.event],rel_options)
     try:
         testport = int(options.port)
